@@ -1,8 +1,8 @@
 # Release information about releasemanager
 
-version = "1.0"
+version = "1.01"
 
-description = ""
+description = "Allows simple, extensible, distributed release management for complex environments."
 long_description = """
 ReleaseManager is a simple, extensible way to manage software releases for complex environments.  If you have a need to manage a dozen or more code bases,
  each with unique build procedures, many of which produce resources that must be installed multiple machines, for multiple environments (prod, dev, qa, etc), then you've come across the same problems releasemanager is designed to solve.
