@@ -137,7 +137,7 @@ class ReleaseManager(object):
         return trans_id
 
     
-    def finish_transaction(self, trans_id, status):
+    def save_transaction(self, trans_id, status):
         trans = self.persistence.Transaction.get_by(id=trans_id)
         trans.status = status
         trans.completed_at = datetime.datetime.now()
@@ -154,10 +154,10 @@ class ReleaseManager(object):
 
 
     def make_history(self, credentials, request_data):
-        """who else thinks a function named make_history is hilarious?  anyone?  ...shut up."""
-        username = credentials.get('username')
-        action = request_data.get('action')
-        project = request_data.get('project')
+        """creates a history record with some defaults"""
+        username = credentials.get('username', 'anonymous')
+        action = request_data.get('action', 'unknown action')
+        project = request_data.get('project', 'unknown project')
         occurred = datetime.datetime.now()
         trans_id = self.getTransaction(request_data)
         hist = self.persistence.History()
@@ -212,6 +212,12 @@ class ReleaseManager(object):
         return True
 
 
+    def report_registrations(self):
+        self._build_registrations()
+        data = {'projects' : [{k : [nt for nt in v.targets]} for k, v in self.projects.items()]}
+        data.update(self.registrations)
+        return data
+
     
     def request_action(self, credentials, request_data):
         """returns tuple of status, payload"""
@@ -241,7 +247,6 @@ class ReleaseManager(object):
         func(credentials, request_data, history=hist)
 
 
-
     def _run_build(self, credentials, request_data, from_install=False, extra=None, history=None):
         project = request_data.get('project')
         if not project:
@@ -292,12 +297,13 @@ class ReleaseManager(object):
         self.logger.log(msg)
         self.save_history(history, status, msg)
         trans_id = self.getTransaction(request_data)
+        self.save_transaction(trans_id, 'BUILD_STARTED')
         trans_status = "BUILD_FAILED"
         if status:
             trans_status = "BUILD_COMPLETED"
-            self.finish_transaction(trans_id, trans_status)
+            self.save_transaction(trans_id, trans_status)
             return resource
-        self.finish_transaction(trans_id, trans_status)
+        self.save_transaction(trans_id, trans_status)
         return False
 
     
@@ -351,8 +357,9 @@ class ReleaseManager(object):
         split_resources = self.split_resource(resource)
         for target in split_resources:
             endpoints[target]['resource'] = split_resources[target]
-            
         # run the real installs against all known release daemons
+        trans_id = self.getTransaction(request_data)
+        self.save_transaction(trans_id, 'INSTALL_STARTED')            
         try:
             trans_status = "INSTALL_COMPLETED"
             for target in proj.targets:
@@ -366,8 +373,7 @@ class ReleaseManager(object):
         except Exception, e:
             self.logger.log("ReleaseManager: Failure to install, error was %s" % str(e))
             trans_status = "INSTALL_FAILED"
-        trans_id = self.getTransaction(request_data)
-        self.finish_transaction(trans_id, trans_status)
+        self.save_transaction(trans_id, trans_status)
 
 
     def remote_install(self, credentials, request_data, data, url, history):
